@@ -99,6 +99,32 @@ class DependentVariable:
         input_dict = _get_dictionary(*args, **kwargs)
         input_keys = input_dict.keys()
 
+        self.__validate_key_value__(input_keys, input_dict)
+
+        if "filename" in kwargs.keys():
+            dictionary["filename"] = kwargs["filename"]
+
+        for key in input_keys:
+            if key in default_keys and key != "sparse_sampling":
+                dictionary[key] = input_dict[key]
+
+        if "sparse_sampling" in input_keys:
+            check_sparse_sampling_key_value(input_dict)
+            for key in input_dict["sparse_sampling"].keys():
+                dictionary["sparse_sampling"][key] = input_dict["sparse_sampling"][key]
+        else:
+            dictionary["sparse_sampling"] = {}
+
+        if dictionary["type"] == "internal":
+            self._type = "internal"
+            self.subtype = InternalDataset(**dictionary)
+
+        if dictionary["type"] == "external":
+            self._type = "external"
+            self.subtype = ExternalDataset(**dictionary)
+
+    @staticmethod
+    def __validate_key_value__(input_keys, input_dict):
         if "type" not in input_keys:
             raise KeyError(
                 "Missing a required `type` key from the DependentVariable object."
@@ -136,28 +162,6 @@ class DependentVariable:
             if "components_url" not in input_keys:
                 raise KeyError(message("components_url", "external"))
 
-        if "filename" in kwargs.keys():
-            dictionary["filename"] = kwargs["filename"]
-
-        for key in input_keys:
-            if key in default_keys and key != "sparse_sampling":
-                dictionary[key] = input_dict[key]
-
-        if "sparse_sampling" in input_keys:
-            check_sparse_sampling_key_value(input_dict)
-            for key in input_dict["sparse_sampling"].keys():
-                dictionary["sparse_sampling"][key] = input_dict["sparse_sampling"][key]
-        else:
-            dictionary["sparse_sampling"] = {}
-
-        if dictionary["type"] == "internal":
-            self._type = "internal"
-            self.subtype = InternalDataset(**dictionary)
-
-        if dictionary["type"] == "external":
-            self._type = "external"
-            self.subtype = ExternalDataset(**dictionary)
-
     def __repr__(self):
         if self.unit.physical_type == "dimensionless":
             return (
@@ -433,10 +437,7 @@ class DependentVariable:
             AttributeError: When modified.
         """
         return json.dumps(
-            self._to_dict(for_display=True),
-            ensure_ascii=False,
-            sort_keys=False,
-            indent=2,
+            self._dict(for_display=True), ensure_ascii=False, sort_keys=False, indent=2,
         )
 
     @property
@@ -755,11 +756,15 @@ class DependentVariable:
         self.subtype._unit = factor.unit
 
     def to_dict(self):
+        """Alias to the `dict()` method of the class."""
+        return self.dict()
+
+    def dict(self):
         """
         Return DependentVariable object as a python dictionary.
 
         Example:
-            >>> y.to_dict() # doctest: +SKIP
+            >>> y.dict() # doctest: +SKIP
             {'type': 'internal', 'description': 'A test image', 'name': 'star',
             'unit': 's * W', 'quantity_name': 'energy', 'encoding': 'none',
             'numeric_type': 'float32', 'quantity_type': 'pixel_3',
@@ -767,13 +772,11 @@ class DependentVariable:
             [10.0, 11.0, 12.0, 13.0, 14.0, 15.0, 16.0, 17.0, 18.0, 19.0],
             [20.0, 21.0, 22.0, 23.0, 24.0, 25.0, 26.0, 27.0, 28.0, 29.0]]}
         """
-        return self.subtype.to_dict()
+        return self.subtype.dict()
 
-    def _to_dict(
-        self, filename=None, dataset_index=None, for_display=False, version=None
-    ):
+    def _dict(self, filename=None, dataset_index=None, for_display=False, version=None):
         """Return DependentVariable object as a python dictionary."""
-        return self.subtype.to_dict(filename, dataset_index, for_display, version)
+        return self.subtype.dict(filename, dataset_index, for_display, version)
 
     def copy(self):
         """Return a copy of the DependentVariable object."""
@@ -869,24 +872,16 @@ def check_sparse_sampling_key_value(input_dict):
         )
 
 
-def as_dependent_variable(
-    array, quantity_type="scalar", unit="", description="", application={}
-):
+def as_dependent_variable(array, **kwargs):
     """Generate and return a DependentVariable object from a 1D or 2D numpy array.
 
     Args:
         array: A 1D or 2D numpy array.
-        quantity_type: The quantity type of the dependent variable. See
-                :ref:`quantityType_uml` for valid quantity types.
-        unit: The unit of the dependent variable components.
-        label: The label along the dimension. The default value is an empty string.
-        description: A description of the dimension. The default value is an empty
-                string.
-        application: An application dictionary. The default is an empty dictionary.
+        kwargs: Additional keyword arguments from the DependentVariable class.
 
     Example:
         >>> array = np.arange(1e4).astype(np.complex128)
-        >>> dim_object = cp.as_dependent_variable(array, )
+        >>> dim_object = cp.as_dependent_variable(array)
         >>> print(dim_object)
         DependentVariable(
         [[0.000e+00+0.j 1.000e+00+0.j 2.000e+00+0.j ... 9.997e+03+0.j
@@ -903,10 +898,7 @@ def as_dependent_variable(
             f"Cannot convert a {array.ndim} dimensional array to a DependentVariable "
             "object."
         )
-    kwargs = {
-        "quantity_type": quantity_type,
-        "unit": unit,
-        "description": description,
-        "application": application,
-    }
+    if "quantity_type" not in kwargs.keys():
+        kwargs["quantity_type"] = "scalar"
+
     return DependentVariable(type="internal", components=array, **kwargs)
