@@ -114,6 +114,19 @@ class Dimension:
                 else:
                     default[key] = input_dict[key]
 
+        self.__validate_key_value__(default)
+
+        if default["type"] == "labeled":
+            self.subtype = LabeledDimension(**default)
+
+        if default["type"] == "monotonic":
+            self.subtype = MonotonicDimension(values=default["coordinates"], **default)
+
+        if default["type"] == "linear":
+            self.subtype = self._linear(default)
+
+    @staticmethod
+    def __validate_key_value__(default):
         _valid_types = ["monotonic", "linear", "labeled"]
 
         type_ = default["type"]
@@ -131,19 +144,11 @@ class Dimension:
                 "Missing a required `labels` key from the LabeledDimension object."
             )
 
-        if default["type"] == "labeled":
-            self.subtype = LabeledDimension(**default)
-
         if default["type"] == "monotonic" and default["coordinates"] is None:
             raise KeyError(
                 "Missing a required `coordinates` key from the MonotonicDimension "
                 "object."
             )
-        if default["type"] == "monotonic":
-            self.subtype = MonotonicDimension(values=default["coordinates"], **default)
-
-        if default["type"] == "linear":
-            self.subtype = self._linear(default)
 
     def _linear(self, default):
         """Create and assign a linear dimension."""
@@ -755,17 +760,21 @@ class Dimension:
         self.subtype._copy_metadata(obj)
 
     def to_dict(self):
+        """Alias to the `dict()` method of the class."""
+        return self.dict()
+
+    def dict(self):
         r"""
         Return Dimension object as a python dictionary.
 
         Example:
-            >>> x.to_dict() # doctest: +SKIP
+            >>> x.dict() # doctest: +SKIP
             {'type': 'linear', 'description': 'This is a test', 'count': 10,
             'increment': '5.0 G', 'coordinates_offset': '10.0 mT',
             'origin_offset': '10.0 T', 'quantity_name': 'magnetic flux density',
             'label': 'field strength'}
         """
-        return self.subtype.to_dict()
+        return self.subtype.dict()
 
     def is_quantitative(self):
         r"""
@@ -815,7 +824,7 @@ class Dimension:
         return self.subtype.reciprocal_coordinates()
 
 
-def as_dimension(array, unit="", type=None, label="", description="", application={}):
+def as_dimension(array, unit="", type=None, **kwargs):
     """Generate and return a Dimension object from a 1D numpy array.
 
     Args:
@@ -823,10 +832,7 @@ def as_dimension(array, unit="", type=None, label="", description="", applicatio
         unit: The unit of the coordinates along the dimension.
         type: The dimension type. Valid values are linear, monotonic, labeled, or
                 None. If the value is None, let us decide. The default value is None.
-        label: The label along the dimension. The default value is an empty string.
-        description: A description of the dimension. The default value is an empty
-                string.
-        application: An application dictionary. The default is an empty dictionary.
+        kwargs: Additional keyword arguments from the Dimension class.
 
     Example:
         >>> array = np.arange(15)*0.5
@@ -839,6 +845,30 @@ def as_dimension(array, unit="", type=None, label="", description="", applicatio
         >>> print(dim_object)
         LabeledDimension(['The' 'great' 'circle'])
     """
+    array = __check_array_for_dimension__(array, type)
+
+    if type is None:
+        return _generic_dimensions(array, unit, **kwargs)
+
+    if type == "linear":
+        obj = _linear_dimension(array, unit, **kwargs)
+        if obj is not None:
+            return obj
+        raise ValueError("Invalid array for LinearDimension object.")
+
+    if type == "monotonic":
+        obj = _monotonic_dimension(array, unit, **kwargs)
+        if obj is not None:
+            return obj
+        raise ValueError("Invalid array for MonotonicDimension object.")
+
+    if type == "labeled":
+        if unit != "":
+            warnings.warn("Ignoring unit argument for LabeledDimension object.")
+        return LabeledDimension(labels=array.tolist(), **kwargs)
+
+
+def __check_array_for_dimension__(array, type):
     options = [None, "linear", "monotonic", "labeled"]
     if type not in options:
         raise ValueError(f"Invalid value for `type`. Allowed values are {options}.")
@@ -847,64 +877,54 @@ def as_dimension(array, unit="", type=None, label="", description="", applicatio
         raise ValueError(
             f"Cannot convert {array.__class__.__name__} to a Dimension object."
         )
-    if isinstance(array, list):
-        array = np.asarray(array)
+
+    array = np.asarray(array)
     if array.ndim != 1:
         raise ValueError(
             f"Cannot convert a {array.ndim} dimensional array to a Dimension object."
         )
+    return array
 
-    kwargs = {"label": label, "description": description, "application": application}
 
-    if type is None:
-        # labeled
-        if str(array.dtype)[:2] in [">U", "<U"]:
-            if unit != "":
-                warnings.warn("Ignoring unit argument for LabeledDimension.")
-            return LabeledDimension(labels=array.tolist(), **kwargs)
-
-        # linear
-        increment = array[1] - array[0]
-        if increment == 0:
-            raise ValueError("Invalid array for Dimension object.")
-
-        if np.allclose(np.diff(array, 1), increment):
-            return LinearDimension(
-                count=array.size,
-                increment=f"{increment} {unit}",
-                coordinates_offset=f"{array[0]} {unit}",
-                **kwargs,
-            )
-
-        # monotonic
-        if np.all(np.diff(array, 1) > 0) or np.all(np.diff(array, 1) < 0):
-            return MonotonicDimension(
-                coordinates=array * string_to_quantity(unit), **kwargs
-            )
-
-        raise ValueError("Invalid array for Dimension object.")
-
-    if type == "linear":
-        increment = array[1] - array[0]
-        if increment == 0:
-            raise ValueError("Invalid array for LinearDimension object.")
-
-        if np.all(np.diff(array, 1) == increment):
-            return LinearDimension(
-                count=array.size,
-                increment=f"{increment} {unit}",
-                coordinates_offset=f"{array[0]} {unit}",
-                **kwargs,
-            )
-
-    if type == "monotonic":
-        if np.all(np.diff(array, 1) > 0) or np.all(np.diff(array, 1) < 0):
-            return MonotonicDimension(
-                coordinates=array * string_to_quantity(unit), **kwargs
-            )
-        raise ValueError("Invalid array for MonotonicDimension object.")
-
-    if type == "labeled":
+def _generic_dimensions(array, unit, className="Dimension", **kwargs):
+    """Return a dimension object based on the array coordinates."""
+    # labeled
+    if str(array.dtype)[:2] in [">U", "<U"]:
         if unit != "":
-            warnings.warn("Ignoring unit argument for LabeledDimension object.")
+            warnings.warn("Ignoring unit argument for LabeledDimension.")
         return LabeledDimension(labels=array.tolist(), **kwargs)
+
+    # linear
+    obj = _linear_dimension(array, unit, className, **kwargs)
+    if obj is not None:
+        return obj
+
+    # monotonic
+    obj = _monotonic_dimension(array, unit, **kwargs)
+    if obj is not None:
+        return obj
+
+    raise ValueError("Invalid array for Dimension object.")
+
+
+def _linear_dimension(array, unit, className="LinearDimension", **kwargs):
+    """Return a LinearDimension is array is linear, else None."""
+    increment = array[1] - array[0]
+    if increment == 0:
+        raise ValueError(f"Invalid array for {className} object.")
+
+    if np.allclose(np.diff(array, 1), increment):
+        return LinearDimension(
+            count=array.size,
+            increment=f"{increment} {unit}",
+            coordinates_offset=f"{array[0]} {unit}",
+            **kwargs,
+        )
+
+
+def _monotonic_dimension(array, unit, **kwargs):
+    """Return a MonotonicDimension is array is monotonic, else None."""
+    if np.all(np.diff(array, 1) > 0) or np.all(np.diff(array, 1) < 0):
+        return MonotonicDimension(
+            coordinates=array * string_to_quantity(unit), **kwargs
+        )
